@@ -75,8 +75,8 @@ using Instance_md_and_gr_member =
 class Cluster_set_impl;
 class ClusterSet;
 
-class Cluster_impl : public Base_cluster_impl,
-                     public shcore::NotificationObserver {
+class Cluster_impl final : public Base_cluster_impl,
+                           public shcore::NotificationObserver {
  public:
   friend class Cluster;
 
@@ -113,6 +113,7 @@ class Cluster_impl : public Base_cluster_impl,
   shcore::Value options(const bool all);
   shcore::Value status(int64_t extended);
   shcore::Value list_routers(bool only_upgrade_required) override;
+  void remove_router_metadata(const std::string &router) override;
   void force_quorum_using_partition_of(const Connection_options &instance_def,
                                        const bool interactive);
   void dissolve(const mysqlshdk::null_bool &force, const bool interactive);
@@ -132,12 +133,12 @@ class Cluster_impl : public Base_cluster_impl,
   shcore::Value create_cluster_set(
       const std::string &domain_name,
       const clusterset::Create_cluster_set_options &options);
-
-  std::shared_ptr<Cluster_set_impl> get_cluster_set(
-      bool print_warnings = false);
+  std::shared_ptr<ClusterSet> get_cluster_set();
 
   Cluster_availability cluster_availability() const { return m_availability; }
 
+  void check_cluster_online();
+
   // Class functions
   void sanity_check() const;
 
@@ -170,6 +171,8 @@ class Cluster_impl : public Base_cluster_impl,
 
   const std::string get_communication_stack() const;
 
+  int64_t get_transaction_size_limit() const;
+
   Cluster_type get_type() const override {
     return Cluster_type::GROUP_REPLICATION;
   }
@@ -190,7 +193,7 @@ class Cluster_impl : public Base_cluster_impl,
   create_replication_user(mysqlshdk::mysql::IInstance *target,
                           bool only_on_target = false,
                           mysqlshdk::mysql::Auth_options creds = {},
-                          bool print_recreate_node = true);
+                          bool print_recreate_node = true) const;
 
   /**
    * Reset the password of the recovery_account or the target instance's
@@ -202,9 +205,10 @@ class Cluster_impl : public Base_cluster_impl,
    *                         target_instance recovery account
    * @param hosts            List of hosts on which the password must be reset
    */
-  void reset_recovery_password(const std::shared_ptr<Instance> &target,
-                               const std::string &recovery_account = "",
-                               const std::vector<std::string> &hosts = {});
+  void reset_recovery_password(
+      const std::shared_ptr<Instance> &target,
+      const std::string &recovery_account = "",
+      const std::vector<std::string> &hosts = {}) const;
 
   /**
    * Recreate the recovery replication account for the instance instance
@@ -215,7 +219,7 @@ class Cluster_impl : public Base_cluster_impl,
    * @param target          Target instance
    */
   std::pair<std::string, std::string> recreate_replication_user(
-      const std::shared_ptr<Instance> &target);
+      const std::shared_ptr<Instance> &target) const;
 
   bool drop_replication_user(mysqlshdk::mysql::IInstance *target,
                              const std::string &endpoint = "",
@@ -322,7 +326,7 @@ class Cluster_impl : public Base_cluster_impl,
    * @return size_t with the number of instances on which the update process
    * failed
    */
-  size_t setup_clone_plugin(bool enable_clone);
+  size_t setup_clone_plugin(bool enable_clone) const;
 
   void execute_in_members(
       const std::vector<mysqlshdk::gr::Member_state> &states,
@@ -346,7 +350,7 @@ class Cluster_impl : public Base_cluster_impl,
   /**
    * Get the primary instance address.
    *
-   * This funtion retrieves the address of a primary instance in the
+   * This function retrieves the address of a primary instance in the
    * cluster. In single primary mode, only one instance is the primary and
    * its address is returned, otherwise it is assumed that multi primary mode
    * is used. In multi primary mode, the address of any available instance
@@ -396,7 +400,7 @@ class Cluster_impl : public Base_cluster_impl,
    * to update the server_id attribute on the instances table.
    */
   void ensure_metadata_has_server_id(
-      const mysqlshdk::mysql::IInstance &target_instance);
+      const mysqlshdk::mysql::IInstance &target_instance) const;
 
   /**
    * Checks for missing metadata recovery account entries, and fix them using
@@ -436,7 +440,7 @@ class Cluster_impl : public Base_cluster_impl,
   std::unique_ptr<mysqlshdk::config::Config> create_config_object(
       const std::vector<std::string> &ignored_instances = {},
       bool skip_invalid_state = false, bool persist_only = false,
-      bool best_effort = false) const;
+      bool best_effort = false, bool allow_cluster_offline = false) const;
 
   void query_group_wide_option_values(
       mysqlshdk::mysql::IInstance *target_instance,
@@ -470,7 +474,7 @@ class Cluster_impl : public Base_cluster_impl,
    * @param target_instance Target instance rejoining the cluster
    */
   void validate_rejoin_gtid_consistency(
-      const mysqlshdk::mysql::IInstance &target_instance);
+      const mysqlshdk::mysql::IInstance &target_instance) const;
 
   /**
    * Enables super_read_only in the whole Cluster
@@ -490,14 +494,17 @@ class Cluster_impl : public Base_cluster_impl,
 
   void invalidate_cluster_set_metadata_cache();
 
-  void refresh_metadata_session();
-
   void set_cluster_set_remove_pending(bool flag) {
     m_cs_md_remove_pending = flag;
   }
 
+  std::shared_ptr<Cluster_set_impl> check_and_get_cluster_set_for_cluster();
+
   bool is_cluster_set_remove_pending() const { return m_cs_md_remove_pending; }
 
+  std::shared_ptr<Cluster_set_impl> get_cluster_set_object(
+      bool print_warnings = false);
+
   /**
    * Reset the password for the Cluster's replication account in use for the
    * ClusterSet replication channel
@@ -506,7 +513,7 @@ class Cluster_impl : public Base_cluster_impl,
    * generated password
    */
   // XXX removethis
-  mysqlshdk::mysql::Auth_options refresh_clusterset_replication_user();
+  mysqlshdk::mysql::Auth_options refresh_clusterset_replication_user() const;
 
   void update_replication_allowed_host(const std::string &host);
 
@@ -530,6 +537,8 @@ class Cluster_impl : public Base_cluster_impl,
                            const shcore::Object_bridge_ref &sender,
                            shcore::Value::Map_type_ref data) override;
 
+  void find_real_cluster_set_primary(Cluster_set_impl *cs) const;
+
   std::string m_group_name;
   mysqlshdk::gr::Topology_mode m_topology_type =
       mysqlshdk::gr::Topology_mode::NONE;
