@@ -62,7 +62,7 @@ namespace cluster {
 constexpr const int k_recovery_start_timeout = 30;
 
 Cluster_join::Cluster_join(
-    Cluster_impl *cluster, mysqlsh::dba::Instance *primary_instance,
+    Cluster_impl *cluster, const mysqlsh::dba::Instance *primary_instance,
     const std::shared_ptr<mysqlsh::dba::Instance> &target_instance,
     const Group_replication_options &gr_options,
     const Clone_options &clone_options, bool interactive,
@@ -478,7 +478,7 @@ void Cluster_join::configure_cluster_set_member() {
     m_cluster->sync_transactions(*m_primary_instance,
                                  k_clusterset_async_channel_name, 0);
 
-    auto cs = m_cluster->get_cluster_set();
+    auto cs = m_cluster->get_cluster_set_object();
 
     auto ar_options = cs->get_clusterset_replication_options();
 
@@ -837,7 +837,7 @@ void ensure_not_auto_rejoining(Instance *instance) {
 
 }  // namespace
 
-bool Cluster_join::check_rejoinable(bool *out_uuid_mistmatch) {
+bool Cluster_join::check_rejoinable(bool *out_uuid_mistmatch, Intent intent) {
   // Check if the instance is part of the Metadata
   auto status = validate_instance_rejoinable(
       *m_target_instance, m_cluster->get_metadata_storage(),
@@ -850,17 +850,35 @@ bool Cluster_join::check_rejoinable(bool *out_uuid_mistmatch) {
           "does not belong to the cluster: '" + m_cluster->get_name() + "'.");
 
     case Instance_rejoinability::ONLINE:
-      current_console()->print_note(
-          m_target_instance->descr() +
-          " is already an active (ONLINE) member of cluster '" +
-          m_cluster->get_name() + "'.");
+      switch (intent) {
+        case Intent::Rejoin:
+          current_console()->print_note(
+              m_target_instance->descr() +
+              " is already an active (ONLINE) member of cluster '" +
+              m_cluster->get_name() + "'.");
+          break;
+        case Intent::Reboot:
+          current_console()->print_note(m_target_instance->descr() +
+                                        " already rejoined the cluster '" +
+                                        m_cluster->get_name() + "'.");
+          break;
+      }
       return false;
 
     case Instance_rejoinability::RECOVERING:
-      current_console()->print_note(
-          m_target_instance->descr() +
-          " is already an active (RECOVERING) member of cluster '" +
-          m_cluster->get_name() + "'.");
+      switch (intent) {
+        case Intent::Rejoin:
+          current_console()->print_note(
+              m_target_instance->descr() +
+              " is already an active (RECOVERING) member of cluster '" +
+              m_cluster->get_name() + "'.");
+          break;
+        case Intent::Reboot:
+          current_console()->print_note(
+              m_target_instance->descr() + " already rejoined the cluster '" +
+              m_cluster->get_name() + "' and is recovering.");
+          break;
+      }
       return false;
 
     case Instance_rejoinability::REJOINABLE:
@@ -918,6 +936,18 @@ void Cluster_join::prepare_reboot() {
   }
 
   check_instance_configuration(checks::Check_type::BOOTSTRAP);
+
+  if (get_executed_gtid_set(*m_target_instance).empty()) {
+    current_console()->print_note(
+        "The target instance '" + m_target_instance->descr() +
+        "' has not been pre-provisioned (GTID set is empty). The "
+        "Shell is unable to determine whether the instance has "
+        "pre-existing data that would be overwritten.");
+
+    throw shcore::Exception("The instance '" + m_target_instance->descr() +
+                                "' has an empty GTID set.",
+                            SHERR_DBA_GTID_SYNC_ERROR);
+  }
 }
 
 void Cluster_join::prepare_join(
@@ -970,15 +1000,18 @@ void Cluster_join::prepare_join(
                                   m_gr_opts.communication_stack.get_safe(),
                                   m_target_instance->get_canonical_port());
   }
+
+  // Set the transaction size limit
+  m_gr_opts.transaction_size_limit = m_cluster->get_transaction_size_limit();
 }
 
-bool Cluster_join::prepare_rejoin(bool *out_uuid_mistmatch) {
+bool Cluster_join::prepare_rejoin(bool *out_uuid_mistmatch, Intent intent) {
   // Validate the options used
   validate_add_rejoin_options();
 
   m_is_autorejoining = check_auto_rejoining(m_target_instance.get());
 
-  if (!check_rejoinable(out_uuid_mistmatch)) return false;
+  if (!check_rejoinable(out_uuid_mistmatch, intent)) return false;
 
   // Verify whether the instance supports the communication stack in use in the
   // Cluster and set it in the options handler
@@ -1004,6 +1037,9 @@ bool Cluster_join::prepare_rejoin(bool *out_uuid_mistmatch) {
   // REJOIN_INSTANCE() NOT: DATA NOT COPIED
   m_cluster->validate_rejoin_gtid_consistency(*m_target_instance);
 
+  // Set the transaction size limit, to ensure no older values are used
+  m_gr_opts.transaction_size_limit = m_cluster->get_transaction_size_limit();
+
   return true;
 }
 
@@ -1533,7 +1569,7 @@ void Cluster_join::join(Recovery_progress_style progress_style) {
   }
 }
 
-void Cluster_join::rejoin() {
+void Cluster_join::rejoin(bool ignore_cluster_set) {
   auto console = current_console();
 
   // Set a Config object for the target instance (required to configure GR).
@@ -1562,9 +1598,8 @@ void Cluster_join::rejoin() {
   // enable skip_slave_start if the cluster belongs to a ClusterSet, and
   // configure the managed replication channel if the cluster is a
   // replica.
-  if (m_cluster->is_cluster_set_member()) {
+  if (!ignore_cluster_set && m_cluster->is_cluster_set_member())
     configure_cluster_set_member();
-  }
 
   // TODO(alfredo) - when clone support is added to rejoin, join() can
   // probably be simplified into create repl user + rejoin() + update metadata
@@ -1603,6 +1638,16 @@ void Cluster_join::rejoin() {
 
     // Set the allowlist to 'AUTOMATIC' to ensure no older values are used
     m_gr_opts.ip_allowlist = "AUTOMATIC";
+
+    // Sync again with the primary Cluster to ensure the replication account
+    // that was just re-created was already replicated to the Replica Cluster,
+    // otherwise, GR won't be able to authenticate using the account and join
+    // the instance to the group.
+    console->print_info();
+    console->print_info(
+        "* Waiting for the Cluster to synchronize with the PRIMARY Cluster...");
+    m_cluster->sync_transactions(*m_primary_instance,
+                                 k_clusterset_async_channel_name, 0);
   }
 
   mysqlsh::dba::join_cluster(*m_target_instance, *m_primary_instance, m_gr_opts,
@@ -1757,6 +1802,27 @@ void Cluster_join::reboot() {
              m_gr_opts.group_name->c_str());
   }
 
+  // Get the value for transaction size limit stored in the Metadata if it
+  // wasn't set by the caller
+  if (m_gr_opts.transaction_size_limit.is_null()) {
+    int64_t transaction_size_limit;
+
+    shcore::Value value;
+    if (m_cluster->get_metadata_storage()->query_cluster_attribute(
+            m_cluster->get_id(), k_cluster_attribute_transaction_size_limit,
+            &value)) {
+      transaction_size_limit = value.as_int();
+    } else {
+      // Use what's set in the instance
+      transaction_size_limit = m_cluster->get_transaction_size_limit();
+    }
+
+    log_info("Using Group Replication transaction size limit: %" PRId64,
+             transaction_size_limit);
+
+    m_gr_opts.transaction_size_limit = transaction_size_limit;
+  }
+
   log_info("Starting cluster with '%s' using account %s",
            m_target_instance->descr().c_str(),
            m_target_instance->get_connection_options().get_user().c_str());
