@@ -95,6 +95,11 @@ Create_replica_cluster::prepare_create_cluster_options() {
 
   options->clone_options = no_clone_options;
 
+  // Set the maximum value for Replica Clusters by default
+  // Required to avoid a failure in the ClusterSet replication channel due to
+  // transaction sizes in the Replica side being bigger than on the source.
+  options->gr_options.transaction_size_limit = static_cast<int64_t>(0);
+
   return options;
 }
 
@@ -446,6 +451,15 @@ std::shared_ptr<Cluster_impl> Create_replica_cluster::create_cluster_object(
         shcore::Value::True());
   }
 
+  // Store the value of group_replication_transaction_size_limit inherited from
+  // the Primary Cluster
+  if (!m_options.dry_run) {
+    m_cluster_set->get_metadata_storage()->update_cluster_attribute(
+        cluster->get_id(), k_cluster_attribute_transaction_size_limit,
+        shcore::Value(m_cluster_set->get_primary_cluster()
+                          ->get_transaction_size_limit()));
+  }
+
   return cluster;
 }
 
@@ -680,7 +694,7 @@ void Create_replica_cluster::prepare() {
   std::string have_ssl = *m_target_instance->get_sysvar_string("have_ssl");
 
   // The instance does not support SSL
-  if (shcore::str_casecmp(have_ssl.c_str(), "YES") != 0 &&
+  if (!shcore::str_caseeq(have_ssl, "YES") &&
       m_ssl_mode == Cluster_ssl_mode::REQUIRED) {
     console->print_error(
         "The ClusterSet's clusterSetReplicationSslMode is 'REQUIRED', "
@@ -698,6 +712,7 @@ void Create_replica_cluster::prepare() {
 shcore::Value Create_replica_cluster::execute() {
   auto console = mysqlsh::current_console();
   shcore::Value ret_val;
+  bool sync_transactions_revert = false;
   shcore::Scoped_callback_list undo_list;
   Async_replication_options ar_options;
 
@@ -720,11 +735,17 @@ shcore::Value Create_replica_cluster::execute() {
               m_target_instance.get(), "", m_options.dry_run);
 
       if (!m_options.dry_run) {
-        undo_list.push_front([=]() {
+        undo_list.push_front([=, &sync_transactions_revert]() {
           log_info("Revert: Dropping replication account '%s'",
                    ar_options.repl_credentials->user.c_str());
           m_cluster_set->get_primary_master()->drop_user(
               ar_options.repl_credentials->user, "%", true);
+
+          if (sync_transactions_revert) {
+            m_cluster_set->sync_transactions(*m_target_instance.get(),
+                                             {k_clusterset_async_channel_name},
+                                             m_options.timeout);
+          }
         });
       }
     }
@@ -787,9 +808,18 @@ shcore::Value Create_replica_cluster::execute() {
     console->print_info(
         "* Configuring ClusterSet managed replication channel...");
 
+    DBUG_EXECUTE_IF("dba_create_replica_cluster_source_delay", {
+      // Simulate high load on the Primary Cluster (lag) by
+      // introducing delay in the replication channel
+      ar_options.master_delay = 5;
+    });
+
     m_cluster_set->update_replica(m_target_instance.get(), m_primary_instance,
                                   ar_options, true, m_options.dry_run);
 
+    // Channel is up, enable transaction sync on revert
+    sync_transactions_revert = true;
+
     // NOTE: This should be done last to allow changes to be replicated
     undo_list.push_back([=]() {
       log_info("Revert: Removing and resetting ClusterSet settings");
@@ -816,7 +846,7 @@ shcore::Value Create_replica_cluster::execute() {
       recreate_recovery_account(cluster, &repl_account_user,
                                 &repl_account_host);
 
-      undo_list.push_front([&]() {
+      undo_list.push_front([=]() {
         log_info("Revert: Dropping replication user '%s'",
                  repl_account_user.c_str());
         m_cluster_set->get_primary_master()->drop_user(repl_account_user,
@@ -901,6 +931,20 @@ shcore::Value Create_replica_cluster::execute() {
 
     log_debug("ClusterSet metadata updates done");
 
+    // Sync with the primary Cluster to ensure the Metadata changes are
+    // propagated to the new Replica Cluster before returning, otherwise, any
+    // attempt to get this Cluster's object from a connection to one of its
+    // members may result in the object having the wrong view of the topology.
+    // i.e. not understanding its part of a ClusterSet
+    console->print_info();
+    console->print_info(
+        "* Waiting for the Cluster to synchronize with the PRIMARY Cluster...");
+    if (!m_options.dry_run) {
+      m_cluster_set->sync_transactions(*m_target_instance.get(),
+                                       {k_clusterset_async_channel_name},
+                                       m_options.timeout);
+    }
+
     console->print_info();
     console->print_info("Replica Cluster '" + m_cluster_name +
                         "' successfully created on ClusterSet '" +
