@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016, 2021, Oracle and/or its affiliates.
+ * Copyright (c) 2016, 2022, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
@@ -101,16 +101,40 @@ void Base_cluster_impl::target_server_invalidated() {
   }
 }
 
-Cluster_check_info Base_cluster_impl::check_preconditions(
+void Base_cluster_impl::check_preconditions(
     const std::string &function_name,
     Function_availability *custom_func_avail) {
   log_debug("Checking '%s' preconditions.", function_name.c_str());
+  bool primary_available = false;
 
   // Makes sure the metadata state is re-loaded on each API call
   m_metadata_storage->invalidate_cached();
-  return check_function_preconditions(
-      api_class(get_type()) + "." + function_name, get_metadata_storage(),
-      get_cluster_server(), custom_func_avail);
+
+  // Makes sure the primary master is reset before acquiring it on each API call
+  m_primary_master.reset();
+
+  try {
+    current_ipool()->set_metadata(get_metadata_storage());
+    acquire_primary();
+    primary_available = true;
+  } catch (const shcore::Exception &e) {
+    if (e.code() == SHERR_DBA_GROUP_HAS_NO_QUORUM) {
+      log_debug(
+          "Cluster has no quorum and cannot process write transactions: %s",
+          e.what());
+    } else if (e.code() == SHERR_DBA_GROUP_MEMBER_NOT_ONLINE) {
+      log_debug("No PRIMARY member available: %s", e.what());
+    } else if (shcore::str_beginswith(
+                   e.what(), "Failed to execute query on Metadata server")) {
+      log_debug("Unable to query Metadata schema: %s", e.what());
+    } else {
+      throw;
+    }
+  }
+
+  check_function_preconditions(api_class(get_type()) + "." + function_name,
+                               get_metadata_storage(), get_cluster_server(),
+                               primary_available, custom_func_avail);
 }
 
 bool Base_cluster_impl::get_gtid_set_is_complete() const {
@@ -139,6 +163,7 @@ void Base_cluster_impl::sync_transactions(
   }
 
   current_console()->print_info();
+  current_console()->print_info();
 }
 
 std::string Base_cluster_impl::make_replication_user_name(
@@ -333,12 +358,8 @@ void Base_cluster_impl::setup_account_common(
 
   // The pool is initialized with the metadata using the current session
   auto metadata = std::make_shared<MetadataStorage>(get_cluster_server());
-  Instance_pool::Auth_options auth_opts;
-  auth_opts.get(get_cluster_server()->get_connection_options());
-  Scoped_instance_pool ipool(options.interactive(), auth_opts);
-  ipool->set_metadata(metadata);
 
-  const auto primary_instance = acquire_primary();
+  const auto primary_instance = get_primary_master();
   auto finally_primary =
       shcore::on_leave_scope([this]() { release_primary(); });
 
@@ -363,7 +384,7 @@ void Base_cluster_impl::setup_account_common(
     }
 
     Setup_account op_setup(username, host, options, grant_list,
-                           *primary_instance);
+                           *primary_instance, get_type());
     // Always execute finish when leaving "try catch".
     auto finally = shcore::on_leave_scope([&op_setup]() { op_setup.finish(); });
     // Prepare the setup_account execution
@@ -385,6 +406,13 @@ void Base_cluster_impl::setup_router_account(
   setup_account_common(username, host, options, Setup_account_type::ROUTER);
 }
 
+void Base_cluster_impl::remove_router_metadata(const std::string &router) {
+  if (!get_metadata_storage()->remove_router(router)) {
+    throw shcore::Exception::argument_error("Invalid router instance '" +
+                                            router + "'");
+  }
+}
+
 void Base_cluster_impl::set_instance_tag(const std::string &instance_def,
                                          const std::string &option,
                                          const shcore::Value &value) {
@@ -415,17 +443,6 @@ void Base_cluster_impl::set_instance_option(const std::string &instance_def,
                                             const shcore::Value &value) {
   check_preconditions("setInstanceOption");
 
-  // Initialize pool with the metadata
-  Instance_pool::Auth_options auth_opts;
-  auth_opts.get(get_cluster_server()->get_connection_options());
-  Scoped_instance_pool ipool(false, auth_opts);
-  ipool->set_metadata(get_metadata_storage());
-
-  // make sure metadata session is using the primary
-  acquire_primary();
-  auto finally_primary =
-      shcore::on_leave_scope([this]() { release_primary(); });
-
   std::string opt_namespace, opt;
   shcore::Value val;
   std::tie(opt_namespace, opt, val) =
@@ -444,8 +461,9 @@ void Base_cluster_impl::set_option(const std::string &option,
       k_min_gr_version,
       TargetType::InnoDBCluster | TargetType::InnoDBClusterSet,
       ReplicationQuorum::State(ReplicationQuorum::States::Normal),
-      ManagedInstance::State::OnlineRW | ManagedInstance::State::OnlineRO,
-      {{metadata::kIncompatibleOrUpgrading, MDS_actions::RAISE_ERROR}}};
+      {{metadata::kIncompatibleOrUpgrading, MDS_actions::RAISE_ERROR}},
+      true,
+      kClusterGlobalStateAnyOk};
 
   std::string opt_namespace, opt;
   shcore::Value val;
@@ -458,12 +476,6 @@ void Base_cluster_impl::set_option(const std::string &option,
   }
   check_preconditions("setOption", custom_precondition);
 
-  // Initialize pool with the metadata
-  Instance_pool::Auth_options auth_opts;
-  auth_opts.get(get_cluster_server()->get_connection_options());
-  Scoped_instance_pool ipool(false, auth_opts);
-  ipool->set_metadata(get_metadata_storage());
-
   // make sure metadata session is using the primary
   acquire_primary();
   auto finally_primary =
