@@ -120,15 +120,15 @@ std::string to_string(Cluster_ssl_mode ssl_mode) {
 }
 
 Cluster_ssl_mode to_cluster_ssl_mode(const std::string &mode) {
-  if (shcore::str_casecmp("AUTO", mode) == 0) {
+  if (shcore::str_caseeq("AUTO", mode)) {
     return Cluster_ssl_mode::AUTO;
-  } else if (shcore::str_casecmp("DISABLED", mode) == 0) {
+  } else if (shcore::str_caseeq("DISABLED", mode)) {
     return Cluster_ssl_mode::DISABLED;
-  } else if (shcore::str_casecmp("REQUIRED", mode) == 0) {
+  } else if (shcore::str_caseeq("REQUIRED", mode)) {
     return Cluster_ssl_mode::REQUIRED;
-  } else if (shcore::str_casecmp("VERIFY_CA", mode) == 0) {
+  } else if (shcore::str_caseeq("VERIFY_CA", mode)) {
     return Cluster_ssl_mode::VERIFY_CA;
-  } else if (shcore::str_casecmp("VERIFY_IDENTITY", mode) == 0) {
+  } else if (shcore::str_caseeq("VERIFY_IDENTITY", mode)) {
     return Cluster_ssl_mode::VERIFY_IDENTITY;
   } else {
     throw std::runtime_error("Unsupported Cluster SSL-mode: " + mode);
@@ -272,7 +272,7 @@ mysqlshdk::db::nullable<Cluster_ssl_mode> resolve_ssl_mode(
   std::string have_ssl_str = *instance.get_sysvar_string("have_ssl");
 
   // The instance supports SSL
-  if (!shcore::str_casecmp(have_ssl_str.c_str(), "YES")) {
+  if (shcore::str_caseeq(have_ssl_str, "YES")) {
     if (have_ssl) *have_ssl = true;
 
     if (ssl_mode == Cluster_ssl_mode::AUTO ||
@@ -330,7 +330,7 @@ void resolve_instance_ssl_mode(const mysqlshdk::mysql::IInstance &instance,
 
   // Get how memberSslMode was configured on the cluster
   Cluster_ssl_mode gr_ssl_mode = to_cluster_ssl_mode(
-      *pinstance.get_sysvar_string("group_replication_ssl_mode"));
+      pinstance.get_sysvar_string("group_replication_ssl_mode").get_safe());
 
   // The cluster REQUIRES SSL
   if (gr_ssl_mode == Cluster_ssl_mode::REQUIRED ||
@@ -351,7 +351,7 @@ void resolve_instance_ssl_mode(const mysqlshdk::mysql::IInstance &instance,
     std::string have_ssl = *instance.get_sysvar_string("have_ssl");
 
     // SSL is not supported on the instance
-    if (shcore::str_casecmp(have_ssl.c_str(), "YES")) {
+    if (!shcore::str_caseeq(have_ssl, "YES")) {
       throw shcore::Exception::runtime_error(
           "Instance '" + instance.descr() +
           "' does not support SSL and cannot join a cluster with SSL "
@@ -731,52 +731,47 @@ bool validate_cluster_group_name(const mysqlshdk::mysql::IInstance &instance,
 bool validate_super_read_only(const mysqlshdk::mysql::IInstance &instance,
                               mysqlshdk::null_bool clear_read_only,
                               bool interactive) {
-  int super_read_only = *instance.get_sysvar_bool("super_read_only");
-  bool super_read_only_changed = false;
+  if (auto super_read_only = *instance.get_sysvar_bool("super_read_only");
+      !super_read_only)
+    return false;
 
-  if (super_read_only) {
-    auto console = mysqlsh::current_console();
+  auto console = mysqlsh::current_console();
 
-    const std::string error_message =
-        "The MySQL instance at '" + instance.descr() +
-        "' currently has the super_read_only system variable set to "
-        "protect it from inadvertent updates from applications.\nYou must "
-        "first unset it to be able to perform any changes to this "
-        "instance.\n"
-        "For more information see: https://dev.mysql.com/doc/refman/en/"
-        "server-system-variables.html#sysvar_super_read_only.";
+  const std::string error_message =
+      "The MySQL instance at '" + instance.descr() +
+      "' currently has the super_read_only system variable set to "
+      "protect it from inadvertent updates from applications.\nYou must "
+      "first unset it to be able to perform any changes to this "
+      "instance.\n"
+      "For more information see: https://dev.mysql.com/doc/refman/en/"
+      "server-system-variables.html#sysvar_super_read_only.";
 
-    if (clear_read_only.is_null() && interactive) {
-      console->print_error(error_message);
-      console->print_para(
-          "You must first unset it to be able to perform any changes to this "
-          "instance.\n"
-          "For more information see: https://dev.mysql.com/doc/refman/en/"
-          "server-system-variables.html#sysvar_super_read_only.");
-
-      if (console->confirm(
-              "Do you want to disable super_read_only and continue?",
-              mysqlsh::Prompt_answer::NO) == mysqlsh::Prompt_answer::NO) {
-        console->print_info();
-        throw shcore::Exception::runtime_error(
-            "Server in SUPER_READ_ONLY mode");
-      } else {
-        console->print_info();
-        clear_read_only = true;
-      }
-    }
-
-    if (clear_read_only.get_safe()) {
-      log_info("Disabling super_read_only on the instance '%s'",
-               instance.descr().c_str());
-      instance.set_sysvar("super_read_only", false);
-      super_read_only_changed = true;
-    } else {
-      console->print_error(error_message);
+  if (clear_read_only.is_null() && interactive) {
+    console->print_error(error_message);
 
+    if (console->confirm("Do you want to disable super_read_only and continue?",
+                         mysqlsh::Prompt_answer::NO) ==
+        mysqlsh::Prompt_answer::NO) {
+      console->print_info();
       throw shcore::Exception::runtime_error("Server in SUPER_READ_ONLY mode");
+    } else {
+      console->print_info();
+      clear_read_only = true;
     }
   }
+
+  bool super_read_only_changed = false;
+  if (clear_read_only.get_safe()) {
+    log_info("Disabling super_read_only on the instance '%s'",
+             instance.descr().c_str());
+    instance.set_sysvar("super_read_only", false);
+    super_read_only_changed = true;
+  } else {
+    console->print_error(error_message);
+
+    throw shcore::Exception::runtime_error("Server in SUPER_READ_ONLY mode");
+  }
+
   return super_read_only_changed;
 }
 
@@ -1421,8 +1416,8 @@ std::string resolve_gr_local_address(
     bool quiet) {
   assert(!raw_report_host.empty());  // First we need to get the report host.
   bool generated = false;
-  bool comm_stack_mysql = shcore::str_casecmp(communication_stack.get_safe(),
-                                              kCommunicationStackMySQL) == 0;
+  bool comm_stack_mysql = shcore::str_caseeq(communication_stack.get_safe(),
+                                             kCommunicationStackMySQL);
 
   // if report host is an IPv6 address, surround it with []
   // The [] are necessary for IPv6 because we later have to append a colon and
@@ -1560,32 +1555,36 @@ std::string resolve_gr_local_address(
 
 std::vector<Instance_gtid_info> filter_primary_candidates(
     const mysqlshdk::mysql::IInstance &server,
-    const std::vector<Instance_gtid_info> &gtid_info) {
+    const std::vector<Instance_gtid_info> &gtid_info,
+    const std::function<bool(const Instance_gtid_info &,
+                             const Instance_gtid_info &)> &on_conflit) {
   using mysqlshdk::mysql::Gtid_set_relation;
 
+  if (gtid_info.empty()) return {};
+
   std::vector<Instance_gtid_info> candidates;
 
-  if (gtid_info.empty()) return candidates;
-
-  const Instance_gtid_info *freshest_instance = nullptr;
+  const Instance_gtid_info *freshest_instance = &gtid_info[0];
+  candidates.push_back(gtid_info[0]);
 
   for (const auto &inst : gtid_info) {
-    Gtid_set_relation rel;
+    if (freshest_instance == &inst) continue;  // ignore the first
 
-    if (!freshest_instance)
-      rel = Gtid_set_relation::CONTAINED;
-    else
-      rel = mysqlshdk::mysql::compare_gtid_sets(
-          server, freshest_instance->gtid_executed, inst.gtid_executed);
+    auto rel = mysqlshdk::mysql::compare_gtid_sets(
+        server, freshest_instance->gtid_executed, inst.gtid_executed);
 
     switch (rel) {
       // Conflicting GTID sets
       case Gtid_set_relation::DISJOINT:
       case Gtid_set_relation::INTERSECTS:
-        throw shcore::Exception("Conflicting transaction sets between " +
-                                    freshest_instance->server + " and " +
-                                    inst.server,
-                                SHERR_DBA_DATA_ERRANT_TRANSACTIONS);
+        if (!on_conflit)
+          throw shcore::Exception("Conflicting transaction sets between " +
+                                      freshest_instance->server + " and " +
+                                      inst.server,
+                                  SHERR_DBA_DATA_ERRANT_TRANSACTIONS);
+
+        if (!on_conflit(*freshest_instance, inst)) return candidates;
+        break;
 
       case Gtid_set_relation::CONTAINED:
         // this has more transactions than the best candidate
