@@ -314,10 +314,11 @@ bool MetadataStorage::check_version(
     try {
       m_md_state = mysqlsh::dba::metadata::check_installed_schema_version(
           m_md_server, &m_md_version, &m_real_md_version, &m_md_version_schema);
-    } catch (const shcore::Exception &e) {
+    } catch (const shcore::Error &e) {
       throw shcore::Exception::mysql_error_with_code(
-          shcore::str_format("Error querying metadata server at %s: %s",
-                             m_md_server->descr().c_str(), e.what()),
+          shcore::str_format(
+              "Failed to execute query on Metadata server %s: %s",
+              m_md_server->descr().c_str(), e.what()),
           e.code());
     }
   }
@@ -596,6 +597,29 @@ void MetadataStorage::update_cluster_attribute(const Cluster_id &cluster_id,
   }
 }
 
+void MetadataStorage::update_clusters_attribute(const std::string &attribute,
+                                                const shcore::Value &value) {
+  if (value) {
+    shcore::sqlstring query(
+        "UPDATE mysql_innodb_cluster_metadata.clusters"
+        " SET attributes = json_set(attributes, '$." +
+            attribute + "', CAST(? as JSON))",
+        0);
+
+    query << value.repr();
+    query.done();
+    execute_sql(query);
+  } else {
+    shcore::sqlstring query(
+        "UPDATE mysql_innodb_cluster_metadata.clusters"
+        " SET attributes = json_remove(attributes, '$." +
+            attribute + "')",
+        0);
+    query.done();
+    execute_sql(query);
+  }
+}
+
 bool MetadataStorage::query_cluster_capability(const Cluster_id &cluster_id,
                                                const std::string &capability,
                                                shcore::Value *out_value) const {
@@ -778,14 +802,18 @@ bool MetadataStorage::get_cluster_for_cluster_name(
  * must be to the current primary cluster.
  */
 Cluster_id MetadataStorage::create_cluster_record(Cluster_impl *cluster,
-                                                  bool adopted) {
+                                                  bool adopted, bool recreate) {
   Cluster_id cluster_id;
 
   try {
-    auto result = execute_sqlf("SELECT uuid()");
-    cluster_id = result->fetch_one_or_throw()->get_string(0);
+    if (!recreate) {
+      auto res = execute_sqlf("SELECT uuid()");
+      cluster_id = res->fetch_one_or_throw()->get_string(0);
+    } else {
+      cluster_id = cluster->get_id();
+    }
 
-    result = execute_sqlf(
+    auto result = execute_sqlf(
         "INSERT INTO mysql_innodb_cluster_metadata.clusters "
         "(cluster_id, cluster_name, description,"
         " cluster_type, primary_mode, attributes)"
@@ -2171,7 +2199,7 @@ std::vector<Router_options_metadata> MetadataStorage::get_routing_options(
     std::string ret;
     for (const auto &opt : k_router_options) {
       if (opt == k_router_option_target_cluster) {
-        ret += ", IF(";
+        ret += ", JSON_QUOTE(IF(";
         ret += prefix;
         ret +=
             "->>'$.target_cluster'='primary', "
@@ -2180,11 +2208,11 @@ std::vector<Router_options_metadata> MetadataStorage::get_routing_options(
             "mysql_innodb_cluster_metadata.clusters c "
             "WHERE c.attributes->>'$.group_replication_group_name' = ";
         ret += prefix;
-        ret += "->>'$.target_cluster' limit 1)) AS target_cluster";
+        ret += "->>'$.target_cluster' limit 1))) AS target_cluster";
       } else {
         ret += ", ";
         ret += prefix;
-        ret += "->>'$.";
+        ret += "->'$.";
         ret += opt;
         ret += "' as ";
         ret += opt;
@@ -2215,9 +2243,8 @@ std::vector<Router_options_metadata> MetadataStorage::get_routing_options(
 
     for (const auto &option : k_router_options) {
       if (!row.is_null(option)) {
-        std::string value = row.get_string(option);
-
-        rom.defined_options.emplace(option, shcore::Value(value));
+        rom.defined_options.emplace(
+            option, shcore::Value::parse(row.get_string(option)));
       }
     }
 
@@ -2398,14 +2425,22 @@ void MetadataStorage::set_clusterset_global_routing_option(
       "?, ?, ";
 
   try {
-    if (value == shcore::Value::Null()) {
-      // Set the default Routing Options
-      for (const auto &opt : k_default_router_options.defined_options) {
-        set_clusterset_global_routing_option(id, opt.first, opt.second);
-      }
+    shcore::Value value_to_set;
+    if (value.type == shcore::Null) {
+      // Get default Routing Option
+      value_to_set = k_default_router_options.defined_options.at(option);
     } else {
-      execute_sqlf(update_call_prefix + "JSON_QUOTE(?));", id, option,
-                   value.as_string());
+      value_to_set = value;
+    }
+
+    assert(value_to_set);
+
+    // The option default value is null
+    if (value_to_set.type == shcore::Null) {
+      execute_sqlf(update_call_prefix + "NULL);", id, option);
+    } else {
+      execute_sqlf(update_call_prefix + "cast(? as JSON));", id, option,
+                   value_to_set.json(false));
     }
   } catch (const shcore::Exception &e) {
     if (e.code() == ER_SIGNAL_EXCEPTION) throw_router_not_found(e.what());
@@ -2415,7 +2450,7 @@ void MetadataStorage::set_clusterset_global_routing_option(
 
 void MetadataStorage::set_routing_option(const std::string &router,
                                          const std::string &clusterset_id,
-                                         const std::string option,
+                                         const std::string &option,
                                          const shcore::Value &value) {
   static const std::string update_call_prefix =
       "call mysql_innodb_cluster_metadata.v2_set_routing_option(?, ?, ?, ";
@@ -2425,8 +2460,8 @@ void MetadataStorage::set_routing_option(const std::string &router,
       execute_sqlf(update_call_prefix + "NULL);", router, clusterset_id,
                    option);
     else
-      execute_sqlf(update_call_prefix + "JSON_QUOTE(?));", router,
-                   clusterset_id, option, value.as_string());
+      execute_sqlf(update_call_prefix + "cast(? as JSON));", router,
+                   clusterset_id, option, value.json(false));
   } catch (const shcore::Exception &e) {
     if (e.code() == ER_SIGNAL_EXCEPTION) throw_router_not_found(e.what());
     throw;
