@@ -179,7 +179,8 @@ class MetadataStorage : public std::enable_shared_from_this<MetadataStorage> {
 
   bool check_all_members_online() const;
 
-  virtual Cluster_id create_cluster_record(Cluster_impl *cluster, bool adopted);
+  virtual Cluster_id create_cluster_record(Cluster_impl *cluster, bool adopted,
+                                           bool recreate);
 
   virtual Cluster_id create_async_cluster_record(Replica_set_impl *cluster,
                                                  bool adopted);
@@ -222,6 +223,8 @@ class MetadataStorage : public std::enable_shared_from_this<MetadataStorage> {
   void update_cluster_attribute(const Cluster_id &cluster_id,
                                 const std::string &attribute,
                                 const shcore::Value &value);
+  void update_clusters_attribute(const std::string &attribute,
+                                 const shcore::Value &value);
 
   void update_cluster_capability(
       const Cluster_id &cluster_id, const std::string &capability,
@@ -407,7 +410,8 @@ class MetadataStorage : public std::enable_shared_from_this<MetadataStorage> {
 
   void set_routing_option(const std::string &router,
                           const std::string &clusterset_id,
-                          const std::string option, const shcore::Value &value);
+                          const std::string &option,
+                          const shcore::Value &value);
 
   /**
    * Get the topology mode of the cluster from the metadata.
