@@ -496,6 +496,12 @@ void Create_cluster::log_used_gr_options() {
     log_info("Using Group Replication Communication Stack: %s",
              m_options.gr_options.communication_stack->c_str());
   }
+
+  if (!m_options.gr_options.transaction_size_limit.is_null()) {
+    log_info(
+        "Using Group Replication transaction size limit: %s",
+        std::to_string(*m_options.gr_options.transaction_size_limit).c_str());
+  }
 }
 
 void Create_cluster::prepare_metadata_schema() {
@@ -707,6 +713,34 @@ shcore::Value Create_cluster::execute() {
                                                     nullptr);
   }
 
+  // Reset GR member actions to avoid BUG#34464526 "Missing
+  // mysql_start_failover_channels_if_primary after upgrade to 8.0.27+"
+  //
+  // When a Cluster is upgraded from 8.0.26 to 8.0.27+, every instance that is
+  // taken out and rejoined back will have the list of available member
+  // actions reduced to the ones available in 8.0.26 (the current primary).
+  // In this particular scenario, the action
+  // 'mysql_start_failover_channels_if_primary' is removed since it's only
+  // available in 8.0.27+.
+  //
+  // As soon as the primary is taken out, upgraded, and rejoined, the member
+  // actions available in the group are the "reduced" ones, meaning
+  // 'mysql_start_failover_channels_if_primary' is not available.
+  //
+  // This results in an error while creating a Replica Cluster since that
+  // action is configured and enabled. Resetting the member actions beforehand
+  // ensures this issue is not seen.
+  if (!m_options.dry_run && m_create_replica_cluster) {
+    try {
+      mysqlshdk::gr::reset_member_actions(*m_target_instance);
+    } catch (...) {
+      log_error("Error resetting Group Replication member actions at %s: %s",
+                m_target_instance->descr().c_str(),
+                format_active_exception().c_str());
+      throw;
+    }
+  }
+
   if (*m_options.multi_primary && !m_options.get_adopt_from_gr()) {
     console->print_info(
         "The MySQL InnoDB Cluster is going to be setup in advanced "
@@ -715,6 +749,11 @@ shcore::Value Create_cluster::execute() {
         "group-replication-limitations.html");
   }
 
+  // Get the current value of group_replication_transaction_size_limit
+  int64_t original_transaction_size_limit =
+      m_target_instance->get_sysvar_int(kGrTransactionSizeLimit).get_safe();
+  ;
+
   shcore::Scoped_callback_list undo_list;
 
   shcore::Value ret_val;
@@ -849,7 +888,7 @@ shcore::Value Create_cluster::execute() {
     undo_list.push_front([&trx]() { trx.rollback(); });
 
     metadata->create_cluster_record(cluster_impl.get(),
-                                    m_options.get_adopt_from_gr());
+                                    m_options.get_adopt_from_gr(), false);
 
     metadata->update_cluster_attribute(
         cluster_impl->get_id(), k_cluster_attribute_replication_allowed_host,
@@ -884,6 +923,22 @@ shcore::Value Create_cluster::execute() {
           shcore::Value(m_options.gr_options.view_change_uuid.get_safe()));
     }
 
+    // Store in the Metadata the value of
+    // group_replication_transaction_size_limit
+    if (m_create_replica_cluster) {
+      metadata->update_cluster_attribute(
+          cluster_impl->get_id(), k_cluster_attribute_transaction_size_limit,
+          shcore::Value(original_transaction_size_limit));
+    } else {
+      // Get and store the current value. If the option was used, the value was
+      // already set by now so we're good
+      metadata->update_cluster_attribute(
+          cluster_impl->get_id(), k_cluster_attribute_transaction_size_limit,
+          shcore::Value(
+              m_target_instance->get_sysvar_int(kGrTransactionSizeLimit)
+                  .get_safe()));
+    }
+
     // Insert instance into the metadata.
     if (m_options.get_adopt_from_gr()) {
       // Adoption from an existing GR group is performed after creating/updating
