@@ -553,23 +553,7 @@ void Instance_cache_builder::fetch_metadata() {
 void Instance_cache_builder::fetch_version() {
   Profiler profiler{"fetching version"};
 
-  const auto result = query("SELECT @@GLOBAL.VERSION;");
-
-  if (const auto row = result->fetch_one()) {
-    using mysqlshdk::utils::Version;
-
-    m_cache.server_version = Version(row->get_string(0));
-
-    if (m_cache.server_version < Version(5, 7, 0)) {
-      m_cache.server_is_5_6 = true;
-    } else if (m_cache.server_version < Version(8, 0, 0)) {
-      m_cache.server_is_5_7 = true;
-    } else {
-      m_cache.server_is_8_0 = true;
-    }
-  } else {
-    THROW_ERROR0(SHERR_DUMP_IC_FAILED_TO_FETCH_VERSION);
-  }
+  m_cache.server_version = Schema_dumper{m_session}.server_version();
 }
 
 void Instance_cache_builder::fetch_explain_select_rows_index() {
@@ -680,14 +664,14 @@ void Instance_cache_builder::fetch_columns() {
         column.type = mysqlshdk::db::dbstring_to_type(
             data_type, row->get_string(6));  // COLUMN_TYPE
         column.csv_unsafe =
-            shcore::str_iendswith(data_type.c_str(), "binary", "blob") ||
+            shcore::str_iendswith(data_type, "binary", "blob") ||
             mysqlshdk::db::Type::Bit == column.type ||
             mysqlshdk::db::Type::Geometry == column.type;
         const auto extra = row->get_string(7, "");  // EXTRA
         column.generated = extra.find(" GENERATED") != std::string::npos;
         column.auto_increment =
             extra.find("auto_increment") != std::string::npos;
-        column.nullable = shcore::str_caseeq(row->get_string(5).c_str(),
+        column.nullable = shcore::str_caseeq(row->get_string(5),
                                              "YES");  // IS_NULLABLE
 
         table_columns[schema_name][table_name].emplace(
@@ -892,7 +876,7 @@ void Instance_cache_builder::fetch_table_indexes() {
 void Instance_cache_builder::fetch_table_histograms() {
   Profiler profiler{"fetching table histograms"};
 
-  if (!has_tables() || !m_cache.server_is_8_0) {
+  if (!has_tables() || !m_cache.server_version.is_8_0) {
     return;
   }
 
@@ -953,7 +937,7 @@ void Instance_cache_builder::fetch_table_partitions() {
   iterate_tables(info, [](const std::string &, const std::string &,
                           Instance_cache::Table *table,
                           const mysqlshdk::db::IRow *row) {
-    if (shcore::str_caseeq_mv(table->engine, "NDB", "NDBCLUSTER")) {
+    if (shcore::str_caseeq(table->engine, "NDB", "NDBCLUSTER")) {
       // Partition selection is disabled for tables employing a storage engine
       // that supplies automatic partitioning, such as NDB. Ignore such tables.
       return;
