@@ -65,7 +65,8 @@ REGISTER_HELP(UTIL_BRIEF,
               "Global object that groups miscellaneous tools like upgrade "
               "checker and JSON import.");
 
-Util::Util(shcore::IShell_core *owner) : _shell_core(*owner) {
+Util::Util(shcore::IShell_core *owner)
+    : Extensible_object("util", "util", true), _shell_core(*owner) {
   expose("checkForServerUpgrade", &Util::check_for_server_upgrade,
          "?connectionData", "?options")
       ->cli();
@@ -82,35 +83,6 @@ Util::Util(shcore::IShell_core *owner) : _shell_core(*owner) {
   expose("exportTable", &Util::export_table, "table", "outputUrl", "?options")
       ->cli();
   expose("loadDump", &Util::load_dump, "url", "?options")->cli();
-
-  // util.debug sub-object, for built-in scripted or C++ features
-  add_property("debug");
-  m_util_debug = std::make_shared<Util_debug>();
-  {
-    auto def = std::make_shared<mysqlsh::Member_definition>();
-
-    def->name = "debug";
-    def->brief = "Debugging and diagnostic utilities.";
-
-    m_util_debug->set_definition(def);
-  }
-  static bool with_help = true;
-
-  m_util_debug->set_registered("", with_help);
-
-  with_help = false;
-}
-
-shcore::Value Util::get_member(const std::string &prop) const {
-  shcore::Value ret_val;
-
-  if (prop == "debug") {
-    ret_val = shcore::Value(m_util_debug);
-  } else {
-    ret_val = Cpp_object_bridge::get_member(prop);
-  }
-
-  return ret_val;
 }
 
 REGISTER_HELP_FUNCTION(checkForServerUpgrade, util);
@@ -1041,8 +1013,8 @@ the files with data size greater than <b>1.5 * bytesPerChunk</b>.
 of previous load attempts to the destination server and loads the whole dump
 again.
 @li <b>schema</b>: string (default not set) - Load the dump into the given
-schema. This option can only be used when loading dumps created by the
-util.<<<dumpTables>>>() function.
+schema. This option can only be used when loading just one schema, (either only
+one schema was dumped, or schema filters result in only one schema).
 @li <b>sessionInitSql</b>: list of strings (default: []) - execute the given
 list of SQL statements in each session about to load data.
 @li <b>showMetadata</b>: bool (default: false) - Displays the metadata
