@@ -110,6 +110,19 @@ class MySQL_upgrade_check_test : public Shell_core_test_wrapper {
     }
   }
 
+  void EXPECT_ISSUE(
+      const Upgrade_issue &actual, const std::string &schema = "",
+      const std::string table = "", const std::string &column = "",
+      Upgrade_issue::Level level = Upgrade_issue::Level::WARNING) {
+    std::string scope{schema + "." + table + "." + column};
+    scope.append("-").append(Upgrade_issue::level_to_string(level));
+    SCOPED_TRACE(scope.c_str());
+    EXPECT_STREQ(schema.c_str(), actual.schema.c_str());
+    EXPECT_STRCASEEQ(table.c_str(), actual.table.c_str());
+    EXPECT_STREQ(column.c_str(), actual.column.c_str());
+    EXPECT_EQ(level, actual.level);
+  }
+
   void EXPECT_NO_ISSUES(Upgrade_check *check) { EXPECT_ISSUES(check, 0); }
 
   Upgrade_check::Upgrade_info info;
@@ -187,25 +200,34 @@ TEST_F(MySQL_upgrade_check_test, reserved_keywords) {
   ASSERT_NO_THROW(
       session->execute("CREATE FUNCTION rows (s CHAR(20)) RETURNS CHAR(50) "
                        "DETERMINISTIC RETURN CONCAT('Hello, ',s,'!');"));
+  ASSERT_NO_THROW(
+      session->execute("CREATE FUNCTION full (s CHAR(20)) RETURNS CHAR(50) "
+                       "DETERMINISTIC RETURN CONCAT('Hello, ',s,'!');"));
   ASSERT_NO_THROW(session->execute(
       "CREATE EVENT LEAD ON SCHEDULE AT CURRENT_TIMESTAMP + INTERVAL 1 "
       "HOUR DO UPDATE System SET JSON_TABLE = JSON_TABLE + 1;"));
 
-  EXPECT_ISSUES(check.get(), 12);
-  EXPECT_EQ("grouping", issues[0].schema);
-  EXPECT_EQ(Upgrade_issue::WARNING, issues[0].level);
-  EXPECT_STRCASEEQ("system", issues[1].table.c_str());
-  EXPECT_EQ("JSON_TABLE", issues[2].column);
-  EXPECT_EQ("cube", issues[3].column);
-  // Views columns are also displayed
-  EXPECT_EQ("JSON_TABLE", issues[4].column);
-  EXPECT_EQ("cube", issues[5].column);
-  EXPECT_EQ("first_value", issues[6].table);
-  EXPECT_STRCASEEQ("LATERAL", issues[7].table.c_str());
-  EXPECT_STRCASEEQ("NTile", issues[8].table.c_str());
-  EXPECT_EQ("Array", issues[9].table);
-  EXPECT_EQ("rows", issues[10].table);
-  EXPECT_EQ("LEAD", issues[11].table);
+  EXPECT_ISSUES(check.get(), 13);
+  EXPECT_ISSUE(issues[0], "grouping");
+  EXPECT_ISSUE(issues[1], "grouping", "System");
+  EXPECT_ISSUE(issues[2], "grouping", "NTile", "JSON_TABLE");
+  EXPECT_ISSUE(issues[3], "grouping", "NTile", "cube");
+  EXPECT_ISSUE(issues[4], "grouping", "System", "JSON_TABLE");
+  EXPECT_ISSUE(issues[5], "grouping", "System", "cube");
+  EXPECT_ISSUE(issues[6], "grouping", "first_value");
+  EXPECT_ISSUE(issues[7], "grouping", "LATERAL");
+  EXPECT_ISSUE(issues[8], "grouping", "NTile");
+  EXPECT_ISSUE(issues[9], "grouping", "Array");
+  EXPECT_ISSUE(issues[10], "grouping", "full");
+  EXPECT_ISSUE(issues[11], "grouping", "rows");
+  EXPECT_ISSUE(issues[12], "grouping", "LEAD");
+
+  check = Sql_upgrade_check::get_reserved_keywords_check(
+      upgrade_info(Version(5, 7, 0), Version(8, 0, 30)));
+  ASSERT_NO_THROW(issues = check->run(session, info));
+  ASSERT_EQ(12, issues.size());
+  EXPECT_ISSUE(issues[10], "grouping", "rows");
+  EXPECT_ISSUE(issues[11], "grouping", "LEAD");
 
   check = Sql_upgrade_check::get_reserved_keywords_check(
       upgrade_info(Version(5, 7, 0), Version(8, 0, 11)));
@@ -213,6 +235,97 @@ TEST_F(MySQL_upgrade_check_test, reserved_keywords) {
   ASSERT_EQ(10, issues.size());
 }
 
+TEST_F(MySQL_upgrade_check_test, syntax_check) {
+  SKIP_IF_NOT_5_7_UP_TO(Version(8, 0, 0));
+  static const char *test_objects[] = {
+      R"*(CREATE PROCEDURE testsp1()
+BEGIN
+  DECLARE rows INT DEFAULT 0;
+  DECLARE ROW  INT DEFAULT 4;
+END)*",
+      R"*(CREATE PROCEDURE testsp1_ok()
+BEGIN
+  DECLARE `rows` INT DEFAULT 0;
+  DECLARE `ROW`  INT DEFAULT 4;
+END)*",
+      R"*(CREATE FUNCTION testf1() RETURNS INT
+BEGIN
+  DECLARE rows INT DEFAULT 0;
+  DECLARE ROW  INT DEFAULT 4;
+  RETURN 0;
+END)*",
+      R"*(CREATE FUNCTION testf1_ok() RETURNS INT
+BEGIN
+  DECLARE `rows` INT DEFAULT 0;
+  DECLARE `ROW`  INT DEFAULT 4;
+  RETURN 0;
+END)*",
+      R"*(CREATE PROCEDURE testsp2()
+BEGIN
+  CREATE TABLE reservedTestTable (
+      ROWS binary(16) NOT NULL,
+      ROW binary(16) NOT NULL,
+      C datetime NOT NULL,
+      D varchar(32) NOT NULL,
+      E longtext NOT NULL,
+      PRIMARY KEY (ROWS,`C`),
+      KEY `BD_idx` (ROW,`D`)
+  ) ENGINE=InnoDB DEFAULT CHARSET=utf8;
+END)*",
+      R"*(CREATE PROCEDURE testsp2_ok()
+BEGIN
+  CREATE TABLE reservedTestTable (
+      `ROWS` binary(16) NOT NULL,
+      `ROW` binary(16) NOT NULL,
+      C datetime NOT NULL,
+      D varchar(32) NOT NULL,
+      E longtext NOT NULL,
+      PRIMARY KEY (`ROWS`,`C`),
+      KEY `BD_idx` (`ROW`,`D`)
+  ) ENGINE=InnoDB DEFAULT CHARSET=utf8;
+END)*",
+      "CREATE TABLE testbl (a int primary key)",
+      R"*(CREATE TRIGGER mytrigger BEFORE INSERT ON testbl FOR EACH ROW
+       BEGIN
+        DECLARE rows INT DEFAULT 0;
+        DECLARE ROW  INT DEFAULT 4;
+      END)*",
+      R"*(CREATE TRIGGER mytrigger_ok BEFORE INSERT ON testbl
+       FOR EACH ROW
+      BEGIN 
+        DECLARE `rows` INT DEFAULT 0;
+        DECLARE `ROW` INT DEFAULT 4;
+      END)*",
+      R"*(CREATE EVENT myevent ON SCHEDULE AT '2000-01-01 00:00:00'
+     ON COMPLETION PRESERVE DO
+     begin
+      DECLARE rows INT DEFAULT 0;
+      DECLARE ROW INT DEFAULT 4;
+     end)*",
+      R"*(CREATE EVENT myevent_ok ON SCHEDULE AT '2000-01-01 00:00:00'
+     ON COMPLETION PRESERVE DO
+     begin
+      DECLARE `rows` INT DEFAULT 0;
+      DECLARE `ROW` INT DEFAULT 4;
+     end)*"};
+
+  auto check = Sql_upgrade_check::get_routine_syntax_check();
+  EXPECT_NE(nullptr, check->get_doc_link());
+  EXPECT_NO_ISSUES(check.get());
+
+  PrepareTestDatabase("testdb");
+  for (const char *sql : test_objects) {
+    ASSERT_NO_THROW(session->execute(sql));
+  }
+
+  EXPECT_ISSUES(check.get(), 5);
+  EXPECT_ISSUE(issues[0], "testdb", "testsp1", "", Upgrade_issue::ERROR);
+  EXPECT_ISSUE(issues[1], "testdb", "testsp2", "", Upgrade_issue::ERROR);
+  EXPECT_ISSUE(issues[2], "testdb", "testf1", "", Upgrade_issue::ERROR);
+  EXPECT_ISSUE(issues[3], "testdb", "mytrigger", "", Upgrade_issue::ERROR);
+  EXPECT_ISSUE(issues[4], "testdb", "myevent", "", Upgrade_issue::ERROR);
+}
+
 TEST_F(MySQL_upgrade_check_test, utf8mb3) {
   SKIP_IF_NOT_5_7_UP_TO(Version(8, 0, 0));
 
@@ -1280,4 +1393,60 @@ TEST_F(MySQL_upgrade_check_test, convert_usage) {
   EXPECT_EQ("b", issues[1].column);
 }
 
+TEST_F(MySQL_upgrade_check_test, columns_which_cannot_have_defaults_check) {
+  SKIP_IF_NOT_5_7_UP_TO(Version(8, 0, 12));
+
+  PrepareTestDatabase("columns_which_cannot_have_defaults_check_test");
+
+  const auto check =
+      Sql_upgrade_check::get_columns_which_cannot_have_defaults_check();
+  EXPECT_EQ(0, strcmp("https://dev.mysql.com/doc/refman/8.0/en/"
+                      "data-type-defaults.html#data-type-defaults-explicit",
+                      check->get_doc_link()));
+
+  EXPECT_NO_ISSUES(check.get());
+
+  // STRICT_TRANS_TABLES needs to be disabled in order for the columns with
+  // types which cannot have defaults could be created
+  ASSERT_NO_THROW(session->execute("set sql_mode='';"));
+  ASSERT_NO_THROW(
+      session->execute("create table t ("
+                       "p point NOT NULL default '',"
+                       "ls linestring NOT NULL default '',"
+                       "poly polygon NOT NULL default '',"
+                       "g geometry NOT NULL default '',"
+                       "mp multipoint NOT NULL default '',"
+                       "mls multilinestring NOT NULL default '',"
+                       "mpoly multipolygon NOT NULL default '',"
+                       "gc geometrycollection NOT NULL default '',"
+                       "j json NOT NULL default '',"
+                       "tb tinyblob NOT NULL default '',"
+                       "b blob NOT NULL default '',"
+                       "mb mediumblob NOT NULL default '',"
+                       "lb longblob NOT NULL default '',"
+                       "tt tinytext NOT NULL default '',"
+                       "t text NOT NULL default '',"
+                       "mt mediumtext NOT NULL default '',"
+                       "lt longtext NOT NULL default ''"
+                       ");"));
+
+  // for some reason, creating a blob/text column with a default value of ''
+  // warns that this column type cannot have a default, but COLUMN_DEFAULT in
+  // INFORMATION_SCHEMA.COLUMNS still holds NULL, and SHOW CREATE TABLE does
+  // not show a default value for such column, hence these columns are not
+  // reported here
+
+  EXPECT_ISSUES(check.get(), 9);
+
+  EXPECT_EQ("p", issues[0].column);
+  EXPECT_EQ("ls", issues[1].column);
+  EXPECT_EQ("poly", issues[2].column);
+  EXPECT_EQ("g", issues[3].column);
+  EXPECT_EQ("mp", issues[4].column);
+  EXPECT_EQ("mls", issues[5].column);
+  EXPECT_EQ("mpoly", issues[6].column);
+  EXPECT_EQ("gc", issues[7].column);
+  EXPECT_EQ("j", issues[8].column);
+}
+
 }  // namespace mysqlsh
