@@ -542,6 +542,39 @@ TEST(utils_string, bits_to_string) {
   TEST_BIT("1111000011110000111100001111000011110000111100001111000011110000");
 }
 
+#define TEST_BIT_HEX(strhex, strbin)                                  \
+  EXPECT_EQ(strhex, bits_to_string_hex(MAKE_BITS(strbin).to_ullong(), \
+                                       sizeof(strbin) - 1));
+
+TEST(utils_string, bits_to_string_hex) {
+  TEST_BIT_HEX("0x00", "0");
+  TEST_BIT_HEX("0x01", "1");
+  TEST_BIT_HEX("0x00", "000");
+  TEST_BIT_HEX("0x01", "0001");
+  TEST_BIT_HEX("0x03", "00011");
+  TEST_BIT_HEX("0xFF", "11111111");
+  TEST_BIT_HEX("0x01FE", "111111110");
+  TEST_BIT_HEX("0xFF00", "1111111100000000");
+  TEST_BIT_HEX("0x01FE00", "11111111000000000");
+  TEST_BIT_HEX("0x00000000015695",
+               "00000000000000000000000000000000000000010101011010010101");
+  TEST_BIT_HEX(
+      "0x00000000002AFC0C",
+      "0000000000000000000000000000000000000000001010101111110000001100");
+  TEST_BIT_HEX(
+      "0xFFFFFFFFFFFFFFFF",
+      "1111111111111111111111111111111111111111111111111111111111111111");
+  TEST_BIT_HEX(
+      "0xAAAAAAAAAAAAAAAA",
+      "1010101010101010101010101010101010101010101010101010101010101010");
+  TEST_BIT_HEX(
+      "0x0F0F0F0F0F0F0F0F",
+      "0000111100001111000011110000111100001111000011110000111100001111");
+  TEST_BIT_HEX(
+      "0xF0F0F0F0F0F0F0F0",
+      "1111000011110000111100001111000011110000111100001111000011110000");
+}
+
 #undef TEST_BIT
 #define TEST_BIT(strvalue)                                                    \
   EXPECT_EQ(MAKE_BITS(strvalue).to_ullong(), string_to_bits(strvalue).first); \
