@@ -110,6 +110,11 @@ Successfully set the value of 'disableClone' to 'false' in the Cluster: 'newName
                 "value": "REQUIRED",
                 "variable": "group_replication_ssl_mode"
             },
+            {
+                "option": "transactionSizeLimit",
+                "value": "[[*]]",
+                "variable": "group_replication_transaction_size_limit"
+            },
             {
                 "option": "disableClone",
                 "value": false
@@ -436,6 +441,11 @@ Successfully set the value of 'disableClone' to 'true' in the Cluster: 'newName'
                 "value": "REQUIRED",
                 "variable": "group_replication_ssl_mode"
             },
+            {
+                "option": "transactionSizeLimit",
+                "value": "[[*]]",
+                "variable": "group_replication_transaction_size_limit"
+            },
             {
                 "option": "disableClone",
                 "value": true
