@@ -794,10 +794,15 @@ DESCRIPTION
       - replicationAllowedHost string value to use as the host name part of
         internal replication accounts. Existing accounts will be re-created
         with the new value.
+      - transactionSizeLimit: integer value to configure the maximum
+        transaction size in bytes which the Cluster accepts
 
       ATTENTION: The failoverConsistency option will be removed in a future
                  release. Please use the consistency option instead.
 
+      ATTENTION: The transactionSizeLimit option is not supported on Replica
+                 Clusters of InnoDB ClusterSets.
+
       The value for the configuration option is used to set the Group
       Replication system variable that corresponds to it.
 
@@ -904,6 +909,18 @@ DESCRIPTION
       the expelled node back to the group. The autoRejoinTries option accepts
       positive integer values and, since 8.0.21, defaults to 3.
 
+      The value for transactionSizeLimit is used to set the Group Replication
+      system variable 'group_replication_transaction_size_limit' and configures
+      the maximum transaction size in bytes which the Cluster accepts.
+      Transactions larger than this size are rolled back by the receiving
+      member and are not broadcast to the Cluster.
+
+      The transactionSizeLimit option accepts positive integer values and, if
+      set to zero, there is no limit to the size of transactions the Cluster
+      accepts
+
+      All members added or rejoined to the Cluster will use the same value.
+
       Tags
 
       Tags make it possible to associate custom key/value pairs to a Cluster,
@@ -1359,17 +1376,18 @@ RETURNS
       Nothing
 
 DESCRIPTION
-      This function fences a PRIMARY Cluster from all Write Traffic by ensuring
-      all of its members are Read-Only regardless of any topology change on it.
-      The Cluster will be put into READ ONLY mode and all members will remain
-      available for reads. To unfence the Cluster so it restores its normal
-      functioning and can accept all traffic use Cluster.unfence().
+      This function fences a Cluster member of a ClusterSet from all Write
+      Traffic by ensuring all of its members are Read-Only regardless of any
+      topology change on it. The Cluster will be put into READ ONLY mode and
+      all members will remain available for reads. To unfence the Cluster so it
+      restores its normal functioning and can accept all traffic use
+      Cluster.unfenceWrites().
 
       Use this function when performing a PRIMARY Cluster failover in a
       ClusterSet to allow only read traffic in the previous Primary Cluster in
       the event of a split-brain.
 
-      The function is not permitted on REPLICA Clusters.
+      The function is not permitted on standalone Clusters.
 
 //@<OUT> unfenceWrites
 NAME
