@@ -360,6 +360,11 @@ Dba.createCluster: The instance '<<<hostname>>>:<<<__mysql_sandbox_port2>>>' has
                 "value": "REQUIRED",
                 "variable": "group_replication_ssl_mode"
             },
+            {
+                "option": "transactionSizeLimit",
+                "value": "[[*]]",
+                "variable": "group_replication_transaction_size_limit"
+            },
             {
                 "option": "disableClone",
                 "value": <<<(__version_num>=80017)?"false":"true">>>
@@ -494,6 +499,11 @@ Dba.createCluster: The instance '<<<hostname>>>:<<<__mysql_sandbox_port2>>>' has
                 "value": "REQUIRED",
                 "variable": "group_replication_ssl_mode"
             },
+            {
+                "option": "transactionSizeLimit",
+                "value": "[[*]]",
+                "variable": "group_replication_transaction_size_limit"
+            },
             {
                 "option": "disableClone",
                 "value": true
@@ -624,6 +634,11 @@ Dba.createCluster: The instance '<<<hostname>>>:<<<__mysql_sandbox_port2>>>' has
                 "value": "REQUIRED",
                 "variable": "group_replication_ssl_mode"
             },
+            {
+                "option": "transactionSizeLimit",
+                "value": "[[*]]",
+                "variable": "group_replication_transaction_size_limit"
+            },
             {
                 "option": "disableClone",
                 "value": true
