@@ -160,7 +160,7 @@ session6.runSql("START group_replication");
 
 // Rejoin the Cluster
 cs.rejoinCluster("cluster2");
-EXPECT_OUTPUT_CONTAINS("* Reconciling internally generated GTIDs");
+EXPECT_OUTPUT_CONTAINS("* Reconciling 1 internally generated GTIDs");
 
 // Purge the binary logs from all members
 // BUG#34013718: reconciliation doesn't happen when binlogs purged from all members
@@ -368,9 +368,6 @@ session3 = mysql.getSession(__sandbox_uri3);
 
 shell.connect(__sandbox_uri1);
 
-// Unable to rejoin instances since this cluster is INVALIDATED
-EXPECT_THROWS_TYPE(function(){dba.rebootClusterFromCompleteOutage("cluster1", {rejoinInstances: [__endpoint2, __endpoint3]});}, "Dba.rebootClusterFromCompleteOutage: removeInstances and/or rejoinInstances options cannot be used for Invalidated Clusters", "ArgumentError");
-
 c1 = dba.rebootClusterFromCompleteOutage("cluster1");
 
 cs.rejoinCluster("cluster1");
@@ -413,37 +410,35 @@ session3.runSql("stop group_replication");
 testutil.killSandbox(__mysql_sandbox_port2);
 testutil.waitMemberState(__mysql_sandbox_port2, "UNREACHABLE");
 
-EXPECT_THROWS(function(){cs.rejoinCluster("cluster2", {dryRun:1});}, "Could not connect to an ONLINE member of Primary Cluster 'cluster1' within quorum");
-
-EXPECT_THROWS(function(){cs.rejoinCluster("cluster2");}, "Could not connect to an ONLINE member of Primary Cluster 'cluster1' within quorum");
+EXPECT_THROWS(function(){cs.rejoinCluster("cluster2", {dryRun:1});}, "The InnoDB Cluster is part of an InnoDB ClusterSet and has global state of NOT_OK within the ClusterSet. Operation is not possible when in that state: Could not connect to an ONLINE member of Primary Cluster within quorum");
 
+EXPECT_THROWS(function(){cs.rejoinCluster("cluster2");}, "The InnoDB Cluster is part of an InnoDB ClusterSet and has global state of NOT_OK within the ClusterSet. Operation is not possible when in that state: Could not connect to an ONLINE member of Primary Cluster within quorum");
 
 //@<> rejoin while primary is offline
 session1.runSql("stop group_replication");
 
-EXPECT_THROWS(function(){cs.rejoinCluster("cluster2", {dryRun:1});}, "All reachable members of Primary Cluster 'cluster1' are OFFLINE, but there are some unreachable members that could be ONLINE");
+EXPECT_THROWS(function(){cs.rejoinCluster("cluster2", {dryRun:1});}, "The InnoDB Cluster is part of an InnoDB ClusterSet and has global state of NOT_OK within the ClusterSet. Operation is not possible when in that state: All reachable members of Primary Cluster are OFFLINE, but there are some unreachable members that could be ONLINE");
 
-EXPECT_THROWS(function(){cs.rejoinCluster("cluster2");}, "All reachable members of Primary Cluster 'cluster1' are OFFLINE, but there are some unreachable members that could be ONLINE");
+EXPECT_THROWS(function(){cs.rejoinCluster("cluster2");}, "The InnoDB Cluster is part of an InnoDB ClusterSet and has global state of NOT_OK within the ClusterSet. Operation is not possible when in that state: All reachable members of Primary Cluster are OFFLINE, but there are some unreachable members that could be ONLINE");
 
 shell.connect(__sandbox_uri6);
 tmpcs= dba.getClusterSet();
-EXPECT_THROWS(function(){tmpcs.rejoinCluster("cluster2");}, "All reachable members of Primary Cluster 'cluster1' are OFFLINE, but there are some unreachable members that could be ONLINE");
+EXPECT_THROWS(function(){tmpcs.rejoinCluster("cluster2");}, "The InnoDB Cluster is part of an InnoDB ClusterSet and has global state of NOT_OK within the ClusterSet. Operation is not possible when in that state: All reachable members of Primary Cluster are OFFLINE, but there are some unreachable members that could be ONLINE");
 
 //@<> rejoin while primary is down
-
 testutil.stopSandbox(__mysql_sandbox_port1, {wait:1});
 testutil.stopSandbox(__mysql_sandbox_port3, {wait:1});
 
 // this will fail because the primary went down
-EXPECT_THROWS(function(){cs.rejoinCluster("cluster2", {dryRun:1});}, "Failed to execute query on Metadata server");
+EXPECT_THROWS(function(){cs.rejoinCluster("cluster2", {dryRun:1});}, "The ClusterSet object is disconnected. Please use dba.getClusterSet() to obtain a fresh handle.");
 
-EXPECT_THROWS(function(){cs.rejoinCluster("cluster2");}, "Failed to execute query on Metadata server");
+EXPECT_THROWS(function(){cs.rejoinCluster("cluster2");}, "The ClusterSet object is disconnected. Please use dba.getClusterSet() to obtain a fresh handle.");
 
 shell.connect(__sandbox_uri6);
 tmpcs= dba.getClusterSet();
-EXPECT_THROWS(function(){tmpcs.rejoinCluster("cluster2", {dryRun:1});}, "Could not connect to any ONLINE member of Primary Cluster 'cluster1'");
+EXPECT_THROWS(function(){tmpcs.rejoinCluster("cluster2", {dryRun:1});}, "The InnoDB Cluster is part of an InnoDB ClusterSet and has global state of NOT_OK within the ClusterSet. Operation is not possible when in that state: Could not connect to any ONLINE member of Primary Cluster");
 
-EXPECT_THROWS(function(){tmpcs.rejoinCluster("cluster2");}, "Could not connect to any ONLINE member of Primary Cluster 'cluster1'");
+EXPECT_THROWS(function(){tmpcs.rejoinCluster("cluster2");}, "The InnoDB Cluster is part of an InnoDB ClusterSet and has global state of NOT_OK within the ClusterSet. Operation is not possible when in that state: Could not connect to any ONLINE member of Primary Cluster");
 
 //@<> Destroy
 testutil.destroySandbox(__mysql_sandbox_port1);
