@@ -179,6 +179,8 @@ DESCRIPTION
         using accounts with this hostname value.
       - communicationStack: The Group Replication protocol stack to be used in
         the Cluster: XCom (legacy) or MySQL.
+      - transactionSizeLimit: integer value to configure the maximum
+        transaction size in bytes which the Cluster accepts
 
       The recoveryMethod option supports the following values:
 
@@ -371,6 +373,18 @@ DESCRIPTION
 
       The default value for Clusters running 8.0.27+ is 'MySQL'.
 
+      The value for transactionSizeLimit is used to set the Group Replication
+      system variable 'group_replication_transaction_size_limit' and configures
+      the maximum transaction size in bytes which the Cluster accepts.
+      Transactions larger than this size are rolled back by the receiving
+      member and are not broadcast to the Cluster.
+
+      The transactionSizeLimit option accepts positive integer values and, if
+      set to zero, there is no limit to the size of transactions the Cluster
+      accepts
+
+      All members added or rejoined to the Cluster will use the same value.
+
 //@<OUT> RemoveCluster
 NAME
       removeCluster - Removes a Replica cluster from a ClusterSet.
@@ -747,6 +761,7 @@ DESCRIPTION
       - target_cluster: Target Cluster for Router routing operations.
       - invalidated_cluster_policy: Routing policy to be taken when the target
         cluster is detected as being invalidated.
+      - stats_updates_frequency: Frequency of Router check-in updates.
 
       The target_cluster option supports the following values:
 
@@ -761,6 +776,18 @@ DESCRIPTION
       - drop_all: all connections to the target Cluster are closed and no new
         connections will be accepted.
 
+      The stats_updates_frequency option accepts positive integers and sets the
+      frequency of Router check-in updates in seconds in the Metadata. If set
+      to 0 ( default), no periodic updates are done. Router will round up the
+      value to be a multiple of Router's TTL, i.e.:
+
+      - If lower than TTL its gets rounded up to TTL, e.g. TTL=30, and
+        stats_updates_frequency=1, effective frequency is 30 seconds.
+      - If not a multiple of TTL it will be rounded up and adjusted according
+        to the TTL, e.g. TTL=5, stats_updates_frequency=11, effective frequency
+        is 15 seconds; TTL=5, stats_updates_frequency=13, effective frequency
+        is 15 seconds.
+
       If the value is null, the option value is cleared and the default value
       takes effect.
 
