@@ -80,7 +80,7 @@ FUNCTIONS
             Drops the Metadata Schema.
 
       get_cluster([name][, options])
-            Retrieves a cluster from the Metadata Store.
+            Returns an object representing a Cluster.
 
       get_cluster_set()
             Returns an object representing a ClusterSet.
@@ -448,6 +448,8 @@ DESCRIPTION
         multiple writable instances. Deprecated.
       - communicationStack: The Group Replication protocol stack to be used in
         the Cluster: XCom (legacy) or MySQL.
+      - transactionSizeLimit: integer value to configure the maximum
+        transaction size in bytes which the Cluster accepts
 
       An InnoDB cluster may be setup in two ways:
 
@@ -655,6 +657,18 @@ DESCRIPTION
 
       The default value for Clusters running 8.0.27+ is 'MySQL'.
 
+      The value for transactionSizeLimit is used to set the Group Replication
+      system variable 'group_replication_transaction_size_limit' and configures
+      the maximum transaction size in bytes which the Cluster accepts.
+      Transactions larger than this size are rolled back by the receiving
+      member and are not broadcast to the Cluster.
+
+      The transactionSizeLimit option accepts positive integer values and, if
+      set to zero, there is no limit to the size of transactions the Cluster
+      accepts
+
+      All members added or rejoined to the Cluster will use the same value.
+
       ATTENTION: The clearReadOnly option will be removed in a future release.
 
       ATTENTION: The multiMaster option will be removed in a future release.
@@ -666,6 +680,8 @@ DESCRIPTION
       ATTENTION: The ipWhitelist option will be removed in a future release.
                  Please use the ipAllowlist option instead.
 
+      ATTENTION: The groupSeeds option will be removed in a future release.
+
 #@<OUT> dba.create_replica_set
 NAME
       create_replica_set - Creates a MySQL InnoDB ReplicaSet.
@@ -862,28 +878,31 @@ DESCRIPTION
 
 #@<OUT> dba.get_cluster
 NAME
-      get_cluster - Retrieves a cluster from the Metadata Store.
+      get_cluster - Returns an object representing a Cluster.
 
 SYNTAX
       dba.get_cluster([name][, options])
 
 WHERE
-      name: Parameter to specify the name of the cluster to be returned.
+      name: Parameter to specify the name of the Cluster to be returned.
       options: Dictionary with additional options.
 
 RETURNS
-      The cluster object identified by the given name or the default cluster.
+      The Cluster object identified by the given name or the default Cluster.
 
 DESCRIPTION
-      If name is not specified or is null, the default cluster will be
+      If name is not specified or is null, the default Cluster will be
       returned.
 
-      If name is specified, and no cluster with the indicated name is found, an
+      If name is specified, and no Cluster with the indicated name is found, an
       error will be raised.
 
-      The options dictionary accepts the connectToPrimary option, which
-      defaults to true and indicates the shell to automatically connect to the
-      primary member of the cluster.
+      The options dictionary may contain the following attributes:
+
+      - connectToPrimary: boolean value used to indicate if Shell should
+        automatically connect to the primary member of the Cluster or not.
+        Deprecated and ignored, Shell will attempt to connect to the primary by
+        default and fallback to a secondary when not possible.
 
 #@<OUT> dba.get_replica_set
 NAME
@@ -985,10 +1004,16 @@ DESCRIPTION
       - user: The user used for the instances sessions required operations.
       - password: The password used for the instances sessions required
         operations.
-      - removeInstances: The list of instances to be removed from the cluster.
-      - rejoinInstances: The list of instances to be rejoined to the cluster.
       - clearReadOnly: boolean value used to confirm that super_read_only must
-        be disabled
+        be disabled.
+      - force: boolean value to indicate that the operation must be executed
+        even if some members of the Cluster cannot be reached, or the primary
+        instance selected has a diverging or lower GTID_SET.
+      - dryRun: boolean value that if true, all validations and steps of the
+        command are executed, but no changes are actually made. An exception
+        will be thrown when finished.
+      - primary: Instance definition representing the instance that must be
+        selected as the primary.
       - switchCommunicationStack: The Group Replication protocol stack to be
         used by the Cluster after the reboot.
       - ipAllowList: The list of hosts allowed to connect to the instance for
@@ -1040,15 +1065,11 @@ DESCRIPTION
 
       ATTENTION: The password option will be removed in a future release.
 
-      This function reboots a cluster from complete outage. It picks the
-      instance the MySQL Shell is connected to as new seed instance and
-      recovers the cluster. Optionally it also updates the cluster
-      configuration based on user provided options.
-
-      NOTE: When used with a metadata version lower than the one supported by
-            this version of the Shell, the removeInstances option is NOT
-            allowed, as in such scenario, no changes to the metadata are
-            allowed.
+      This function reboots a cluster from complete outage. It obtains the
+      Cluster information from the instance MySQL Shell is connected to and
+      uses the most up-to-date instance in regards to transactions as new seed
+      instance to recover the cluster. The remaining Cluster members are
+      automatically rejoined.
 
       On success, the restored cluster object is returned by the function.
 
@@ -1059,6 +1080,9 @@ DESCRIPTION
 
       NOTE: The user and password options are no longer used, the connection
             data is taken from the active shell session.
+      
+      NOTE: The clearReadOnly option is no longer used, super_read_only is
+            automatically cleared.
 
 #@<OUT> dba.start_sandbox_instance
 NAME
