@@ -337,6 +337,10 @@ Rejoining instance '<<<hostname>>>:<<<__mysql_sandbox_port3>>>' to cluster 'devC
 ?{VER(>=8.0.27)}
 Re-creating recovery account...
 NOTE: User '<<<repl_user>>>'@'%' already existed at instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>'. It will be deleted and created again with a new password.
+
+* Waiting for the Cluster to synchronize with the PRIMARY Cluster...
+
+
 ?{}
 <<<(__version_num<80000) ? "WARNING: Instance '"+hostname+":"+__mysql_sandbox_port1+"' cannot persist configuration since MySQL version "+__version+" does not support the SET PERSIST command (MySQL version >= 8.0.11 required). Please use the dba.configureLocalInstance() command locally to persist the changes.\n":""\>>>
 <<<(__version_num<80000) ? "WARNING: Instance '"+hostname+":"+__mysql_sandbox_port2+"' cannot persist configuration since MySQL version "+__version+" does not support the SET PERSIST command (MySQL version >= 8.0.11 required). Please use the dba.configureLocalInstance() command locally to persist the changes.\n":""\>>>
@@ -398,7 +402,6 @@ The cluster was successfully dissolved.
 Replication was disabled but user data was left intact.
 
 //@ Cluster: no operations can be done on an offline cluster
-||Can't access object member 'name' on an offline cluster
 ||Can't call function 'addInstance' on an offline cluster
 ||Can't call function 'checkInstanceState' on an offline cluster
 ||Can't call function 'describe' on an offline cluster
@@ -410,7 +413,7 @@ Replication was disabled but user data was left intact.
 ||Can't call function 'rescan' on an offline cluster
 ||Can't call function 'status' on an offline cluster
 ||Can't call function 'listRouters' on an offline cluster
-||The cluster object is disconnected. Please use dba.getCluster to obtain a fresh cluster handle. (RuntimeError)
+||The cluster object is disconnected. Please use dba.getCluster() to obtain a fresh cluster handle. (RuntimeError)
 
 //@ Cluster: disconnect() is ok on an offline cluster
 ||
