@@ -114,14 +114,14 @@ function genlog_filter_reads(logs, pattern) {
     for (log of logs) {
       sql = log["sql"];
       if (pattern === undefined) {
-        if (sql.match(/select.*from.*/i) ||
+        if (sql.match("select 1") || sql.match(/select.*from.*/i) ||
             sql.match(/(show|begin|start transaction|rollback|.*@@hostname|.*@@server_uuid|select.*gtid)/i) ||
             sql.match(/set (session|@)/i)) {
         } else {
           out.push(log);
         }
       } else {
-        if (sql.match(pattern)) {
+        if (sql.match(pattern) || sql.match("select 1")) {
         } else {
           out.push(log);
         }
@@ -497,14 +497,21 @@ function disable_auto_rejoin(session, port) {
   // Check if the variable session is an int, if so it's the member_port and we need to establish a session
   if (typeof session == "number") {
     var port = session;
-    session = shell.connect("mysql://root:root@localhost:" + session);
+    session = shell.openSession("mysql://root:root@localhost:" + session);
     close_session = true;
   }
 
   testutil.changeSandboxConf(port, "group_replication_start_on_boot", "OFF");
 
-  if (__version_num > 80011)
-    session.runSql("RESET PERSIST group_replication_start_on_boot");
+  if (__version_num > 80011) {
+    try {
+      session.runSql("RESET PERSIST group_replication_start_on_boot");
+    } catch (e) {
+      if (e["code"] != 3615) {
+        throw e;
+      }
+    }
+  }
 
   // Close the session if established in this function
   if (close_session)
